==> percona-xtrabackup_8.4.0-1.orig.tar.gz: percona-xtrabackup-8.4.0-1/router/src/metadata_cache/src/group_replication_metadata.h <==
/*
  Copyright (c) 2016, 2024, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef GROUP_REPLICATION_METADATA_INCLUDED
#define GROUP_REPLICATION_METADATA_INCLUDED

#include <cstdint>
#include <map>
#include <string>
#include <vector>

namespace mysqlrouter {
class MySQLSession;
}

struct GroupReplicationMember {
  enum class State {
    Online,
    Recovering,
    Unreachable,
    Offline,
    Error,
    Other,
  };
  enum class Role {
    Primary,
    Secondary,
  };
  std::string member_id;
  std::string host;
  uint16_t port;
  State state;
  Role role;
};

/** Fetches the list of group replication members known to the instance of the
 * given connection.
 *
 * throws metadata_cache::metadata_error
 */
std::map<std::string, GroupReplicationMember> fetch_group_replication_members(
    mysqlrouter::MySQLSession &connection, bool &single_primary);

const char *to_string(GroupReplicationMember::State member_state);

#endif

==> percona-xtrabackup-80_8.0.35-30.orig.tar.gz: percona-xtrabackup-8.0.35-30/router/src/metadata_cache/src/group_replication_metadata.h <==
/*
  Copyright (c) 2016, 2023, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef GROUP_REPLICATION_METADATA_INCLUDED
#define GROUP_REPLICATION_METADATA_INCLUDED

#include <cstdint>
#include <map>
#include <string>
#include <vector>

namespace mysqlrouter {
class MySQLSession;
}

struct GroupReplicationMember {
  enum class State {
    Online,
    Recovering,
    Unreachable,
    Offline,
    Error,
    Other,
  };
  enum class Role {
    Primary,
    Secondary,
  };
  std::string member_id;
  std::string host;
  uint16_t port;
  State state;
  Role role;
};

/** Fetches the list of group replication members known to the instance of the
 * given connection.
 *
 * throws metadata_cache::metadata_error
 */
std::map<std::string, GroupReplicationMember> fetch_group_replication_members(
    mysqlrouter::MySQLSession &connection, bool &single_primary);

const char *to_string(GroupReplicationMember::State member_state);

#endif
